@@ -1,7 +1,6 @@
 import re
 
-
-def personality(junos, facts):
+def facts_personality(junos, facts):
 
     model = facts['model']
 
@@ -13,16 +12,21 @@ def personality(junos, facts):
                 examine = facts[fact]['model']
                 break
 
+    examine = examine.upper()
+
     if re.match("^(EX)|(QFX)", examine):
         persona = 'SWITCH'
     elif examine.startswith("MX"):
         persona = 'MX'
-    elif examine.startswith("vMX"):
+    elif examine.startswith('VMX'):
         facts['virtual'] = True
         persona = 'MX'
     elif examine.startswith("VJX"):
         facts['virtual'] = True
         persona = 'SRX_BRANCH'
+    elif 'VRR' == examine:
+        persona = "MX"
+        facts['virtual'] = True
     elif examine.startswith("M"):
         persona = "M"
     elif examine.startswith("T"):
@@ -36,7 +40,10 @@ def personality(junos, facts):
     elif re.search("firefly", examine, re.IGNORECASE):
         facts['virtual'] = True
         persona = 'SRX_BRANCH'
+    elif 'OLIVE' == examine:
+        facts['virtual'] = True
+        persona = 'OLIVE'
     else:
-        raise RuntimeError("Unknown device persona: %s" % examine)
+        persona = "UNKNOWN"
 
     facts['personality'] = persona
