@@ -1,4 +1,5 @@
 from __future__ import absolute_import
+import inspect
 
 import paramiko
 from scp import SCPClient
@@ -29,6 +30,8 @@ class SCP(object):
         :param kvargs scpargs: any additional args to be passed to paramiko SCP
         """
         self._junos = junos
+        if self._junos.__dict__.get('_mode') is not None:
+            raise RuntimeError('SCP is not supported with Console mode')
         self._scpargs = scpargs
         self._by10pct = 0
         self._user_progress = self._scpargs.get('progress')
@@ -38,7 +41,8 @@ class SCP(object):
             # User case also define progress with 3 params, the way scp module
             # expects. Function will take path, total size, transferred.
             # https://github.com/jbardin/scp.py/blob/master/scp.py#L97
-            if self._user_progress.func_code.co_argcount == 3:
+            spec = inspect.getargspec(self._user_progress)
+            if len(spec.args) == 3:
                 self._scpargs['progress'] = self._user_progress
             else:
                 # this will override the function _progress defined for this
@@ -49,7 +53,7 @@ class SCP(object):
 
     def _progress(self, report):
         """ simple progress report function """
-        print self._junos.hostname + ": " + report
+        print (self._junos.hostname + ": " + report)
 
     def _scp_progress(self, _path, _total, _xfrd):
 
@@ -69,11 +73,8 @@ class SCP(object):
 
         .. note:: This method uses the same username/password authentication
                    credentials as used by :class:`jnpr.junos.device.Device`.
-
-        .. warning:: The :class:`jnpr.junos.device.Device` ``ssh_private_key_file``
-                     option is currently **not** supported.
-
-        .. todo:: add support for ``ssh_private_key_file``.
+                   It can also use ``ssh_private_key_file`` option if provided
+                   to the :class:`jnpr.junos.device.Device` 
 
         :returns: SCPClient object
         """
@@ -88,6 +89,7 @@ class SCP(object):
         # through a jumphost.
 
         config = {}
+        kwargs = {}
         ssh_config = getattr(junos, '_sshconf_path')
         if ssh_config:
             config = paramiko.SSHConfig()
@@ -97,6 +99,9 @@ class SCP(object):
         if config.get("proxycommand"):
             sock = paramiko.proxy.ProxyCommand(config.get("proxycommand"))
 
+        if self._junos._ssh_private_key_file is not None:
+            kwargs['key_filename']=self._junos._ssh_private_key_file
+
         self._ssh.connect(hostname=junos._hostname,
                           port=(
                               22, int(
@@ -104,7 +109,7 @@ class SCP(object):
                               junos._hostname == 'localhost'],
                           username=junos._auth_user,
                           password=junos._auth_password,
-                          sock=sock
+                          sock=sock, **kwargs
                           )
         return SCPClient(self._ssh.get_transport(), **scpargs)
 
