@@ -2,6 +2,7 @@
 import hashlib
 import re
 from os import path
+import sys
 
 # 3rd-party modules
 from lxml.builder import E
@@ -9,6 +10,7 @@ from lxml.builder import E
 # local modules
 from jnpr.junos.utils.util import Util
 from jnpr.junos.utils.scp import SCP
+from jnpr.junos.utils.ftp import FTP
 from jnpr.junos.exception import SwRollbackError, RpcTimeoutError, RpcError
 
 """
@@ -107,7 +109,7 @@ class SW(Util):
     @classmethod
     def progress(cls, dev, report):
         """ simple progress report function """
-        print dev.hostname + ": " + report
+        print (dev.hostname + ": " + report)
 
     # -------------------------------------------------------------------------
     # put - SCP put the image onto the device
@@ -128,9 +130,14 @@ class SW(Util):
           uses :meth:`scp._scp_progress` for basic reporting by default.
           See that class method for details.
         """
-        # execute the secure-copy with the Python SCP module
-        with SCP(self._dev, progress=progress) as scp:
-            scp.put(package, remote_path)
+        # execute FTP when connection mode if telnet
+        if hasattr(self._dev, '_mode') and self._dev._mode=='telnet':
+            with FTP(self._dev) as ftp:
+                ftp.put(package, remote_path)
+        else:
+            # execute the secure-copy with the Python SCP module
+            with SCP(self._dev, progress=progress) as scp:
+                scp.put(package, remote_path)
 
     # -------------------------------------------------------------------------
     # pkgadd - used to perform the 'request system software add ...'
@@ -211,9 +218,10 @@ class SW(Util):
             rsp = self.rpc.get_checksum_information(path=remote_package, dev_timeout=timeout)
             return rsp.findtext('.//checksum').strip()
         except RpcError as e:
+
             # e.errs is list of dictionaries
             if hasattr(e, 'errs') and \
-                    filter(lambda x: 'No such file or directory' in x['message'], e.errs):
+                    list(filter(lambda x: 'No such file or directory' in x['message'], e.errs)):
                 return None
             else:
                 raise
@@ -393,7 +401,7 @@ class SW(Util):
 
         if no_copy is False:
             copy_ok = True
-            if isinstance(package, (str, unicode)):
+            if (sys.version<'3' and isinstance(package, (str, unicode))) or isinstance(package, str):
                 copy_ok = self.safe_copy(package, remote_path=remote_path,
                                          progress=progress, cleanfs=cleanfs,
                                          checksum=checksum)
